@@ -24,20 +24,27 @@ class Die(Exception):
         
 
 try:
+    required = 'Requires at least SIP-4.6 and its development tools.'
     import sipconfig
 except ImportError:
-    raise Die, 'At least SIP-4.4 and its development tools are required.'
+    raise Die, required
+if 0x040600 > sipconfig._pkg_config['sip_version']:
+    raise Die, required
+del required
 
 
 def get_pyqt_configuration(options):
     """Return the PyQt configuration for Qt3 or Qt4
     """
+    required = 'Requires at least PyQt-3.17 and its development tools.'
     options.qwt = 'qwt4qt3'
     options.iqt = 'iqt4qt3'
     try:
         import pyqtconfig as pyqtconfig
     except ImportError:
-        raise Die, 'At least PyQt-3.16 and its development tools are required.'
+        raise Die, required
+    if 0x031100 > pyqtconfig._pkg_config['pyqt_version']:
+        raise Die, required
 
     try:
         configuration = pyqtconfig.Configuration()
@@ -284,16 +291,16 @@ def check_numpy(configuration, options, package):
 
 
 def check_compiler(configuration, options):
-    """Check compiler specifics
+    """Check compiler specifics.
     """
-    print 'Do not get upset by error messages in the next 6 compiler checks:'
+    print 'Do not get upset by error messages in the next 3 compiler checks:'
     
     makefile = sipconfig.Makefile(configuration)
     generator = makefile.optional_string('MAKEFILE_GENERATOR', 'UNIX')
     if generator in ['MSVC', 'MSVC.NET']:
         options.extra_cxxflags.extend(['-GR'])
 
-    program = os.linesep.join([
+    program = '\n'.join([
         r'#include <stddef.h>',
         r'class a { public: void f(size_t); };',
         r'void a::f(%s) {};',
@@ -304,11 +311,10 @@ def check_compiler(configuration, options):
     new = [
         '// Automagically generated by configure.py',
         '',
-        '// Uncomment one of the following four lines',
+        '// Uncomment one of the following three lines',
         ]
 
-    for ctype in ('int', 'long', 'long long',
-                  'unsigned int', 'unsigned long', 'unsigned long long'):
+    for ctype in ('unsigned int', 'unsigned long', 'unsigned long long'):
         open(name, "w").write(program % ctype)
         print "Check if 'size_t' and '%s' are the same type:" % ctype
         if compile_qt_program(name, configuration):
@@ -316,7 +322,7 @@ def check_compiler(configuration, options):
             print "YES"
         else:
             print "NO"
-            comment =  '//'
+            comment = '// '
         new.append('%stypedef %s size_t;' % (comment, ctype))
 
     new.extend(['',
@@ -327,8 +333,6 @@ def check_compiler(configuration, options):
                 '',
                 ])
 
-    # Warning: I have got two bug reports that SIP-4.4 does not parse \r\n on
-    # Windows (is this true?), so '\n'.join() instead of os.linesep.join(). 
     new = '\n'.join(new)
     types_sip = os.path.join(os.pardir, 'sip', options.qwt, 'QwtTypes.sip')
     if os.access(types_sip, os.R_OK):
@@ -344,7 +348,7 @@ def check_compiler(configuration, options):
 
 
 def check_os(configuration, options):
-    """Adapt to different operating systems
+    """Check operating system specifics.
     """
     print "Found '%s' operating system:" % os.name
     print sys.version
@@ -365,30 +369,21 @@ def check_sip(configuration, options):
     
     print "Found SIP-%s." % version_str
 
-    if 0x040400 <= version:
-        pass
-    else:
-        raise Die, 'PyQwt requires SIP-4.4.x.'
+    if 0x040600 > version:
+        raise Die, 'PyQwt requires at least SIP-4.6.'
 
     return options
 
-# check_sip
+# check_sip()
 
 
 def check_iqt(configuration, options):
-    """Check if building of the iqt package is possible
+    """Check iqt module specifics.
     """
-    try:
-        import readline
-        if os.name == 'nt':
-            print 'The iqt module will not be built on Windows.'
-        else:
-            options.subdirs.append(options.iqt)
-            options.modules.append('iqt')
-            options.iqt_sipfile = os.path.join(
-                os.pardir, 'sip', options.iqt, 'IQtModule.sip')
-    except ImportError:
-        pass
+    options.subdirs.append(options.iqt)
+    options.modules.append('iqt')
+    options.iqt_sipfile = os.path.join(
+        os.pardir, 'sip', options.iqt, 'IQtModule.sip')
 
     return options
 
@@ -396,7 +391,7 @@ def check_iqt(configuration, options):
 
 
 def check_qwt(configuration, options):
-    """Check if building of the qwt package is possible
+    """Check qwt module specifics.
     """
     # zap all qwt_version_info*
     for name in glob.glob('qwt_version_info*'):
@@ -405,7 +400,7 @@ def check_qwt(configuration, options):
         except OSError:
             pass
 
-    program = os.linesep.join([
+    program = '\n'.join([
         r'#include <stdio.h>',
         r'#include <qwt_global.h>',
         r'',
@@ -534,7 +529,7 @@ def setup_iqt_build(configuration, options, package):
         configuration  = configuration,
         build_file = os.path.basename(build_file),
         dir = build_dir,
-        install_dir = options.package_install_path,
+        install_dir = options.module_install_path,
         qt = 1,
         warnings = 1,
         debug = options.debug
@@ -643,6 +638,15 @@ def setup_qwt4_build(configuration, options, package):
     if not os.path.exists(build_file):
         raise Die, 'SIP failed to generate the C++ code.'
 
+    # FIXME: sip-4.7 does not generate those include files anymore
+    for name in [os.path.join(tmp_dir, name) for name in [
+        'sipQwtQwtArrayDouble.h',
+        'sipQwtQwtArrayInt.h',
+        'sipQwtQwtArrayQwtDoublePoint.h',
+        ]]:
+        if not os.path.exists(name):
+            open(name, 'w')
+
     # fix the SIP build file
     fix_build_file(build_file,
                    [os.path.basename(f) for f in extra_sources],
@@ -666,12 +670,12 @@ def setup_qwt4_build(configuration, options, package):
     print '%s file(s) lazily copied.' % lazy_copies
 
     # byte-compile the Python files
-    compileall.compile_dir(build_dir, 1, options.package_install_path)
+    compileall.compile_dir(build_dir, 1, options.module_install_path)
 
     # files to be installed
     installs = []
     installs.append([[os.path.basename(f) for f in glob.glob(
-        os.path.join(build_dir, '*.py*'))], options.package_install_path])
+        os.path.join(build_dir, '*.py*'))], options.module_install_path])
 
     pattern = os.path.join(os.pardir, 'sip', options.qwt, '*.sip')
     installs.append(
@@ -688,7 +692,7 @@ def setup_qwt4_build(configuration, options, package):
         configuration = configuration,
         build_file = os.path.basename(build_file),
         dir = build_dir,
-        install_dir = options.package_install_path,
+        install_dir = options.module_install_path,
         installs = installs,
         qt = 1,
         warnings = 1,
@@ -806,27 +810,28 @@ def parse_args():
     
     detection_options = optparse.OptionGroup(parser, 'Detection options')
     detection_options.add_option(
-        '--disable-numarray',
-        default=False,
-        action='store_true',
+        '--disable-numarray', default=False, action='store_true',
         help='disable detection and use of numarray [default enabled]'
         )
     detection_options.add_option(
-        '--disable-numeric',
-        default=False,
-        action='store_true',
+        '--disable-numeric', default=False, action='store_true',
         help='disable detection and use of Numeric [default enabled]'
         )
     detection_options.add_option(
-        '--disable-numpy',
-        default=False,
-        action='store_true',
+        '--disable-numpy', default=False, action='store_true',
         help='disable detection and use of NumPy [default enabled]'
         )
     parser.add_option_group(detection_options)
 
-    options, args = parser.parse_args()
+    install_options = optparse.OptionGroup(parser, 'Install options')
+    install_options.add_option(
+        '--module-install-path', default='', action='store',
+        help= 'specify the install directory for the Python modules'
+        )
+    parser.add_option_group(install_options)
     
+    options, args = parser.parse_args()
+
     # tweak some of the options to facilitate later processing
     if options.jobs < 1:
         options.jobs = ''
@@ -879,8 +884,9 @@ def main():
     options = check_numpy(configuration, options, 'PyQwt')
     options = check_iqt(configuration, options)
     options = check_qwt(configuration, options)
-    options.package_install_path = os.path.join(
-        configuration.pyqt_mod_dir, 'Qwt4')
+    if not options.module_install_path:
+        options.module_install_path = os.path.join(
+            configuration.pyqt_mod_dir, 'Qwt4')
 
     print
     print 'Extended command line options:'
